@@ -27,7 +27,7 @@ except ImportError:  # pragma: no cover
     # We only actually need these imports when running the mypy checks
     pass
 
-__version__ = "1.10.1"
+__version__ = "2.0.0"
 USER_AGENT_SUFFIX = "AwsEncryptionSdkPython/{}".format(__version__)
 
 
@@ -261,10 +261,6 @@ class AlgorithmSuite(Enum):  # pylint: disable=too-many-instance-attributes
         upper_bytes = self.id_as_bytes()[0]
         return upper_bytes in (0x04, 0x05)
 
-    def is_signing(self):
-        """Determine whether this algorithm suite includes signing."""
-        return self.signing_algorithm_info is not None
-
     def message_id_length(self):
         """Returns the size of the message id."""
         if self.message_format_version == 0x01:
@@ -376,3 +372,5 @@ class CommitmentPolicy(Enum):
     """Controls algorithm suites that can be used on encryption and decryption."""
 
     FORBID_ENCRYPT_ALLOW_DECRYPT = 0
+    REQUIRE_ENCRYPT_ALLOW_DECRYPT = 1
+    REQUIRE_ENCRYPT_REQUIRE_DECRYPT = 2
