@@ -28,7 +28,6 @@ from aws_encryption_sdk.exceptions import (
     AWSEncryptionSDKClientError,
     CustomMaximumValueExceeded,
     MasterKeyProviderError,
-    MaxEncryptedDataKeysExceeded,
     NotSupportedError,
     SerializationError,
 )
@@ -56,8 +55,10 @@ from aws_encryption_sdk.internal.formatting.serialize import (
     serialize_non_framed_close,
     serialize_non_framed_open,
 )
-from aws_encryption_sdk.internal.utils.commitment import validate_commitment_policy_on_encrypt
-from aws_encryption_sdk.internal.utils.signature import SignaturePolicy, validate_signature_policy_on_decrypt
+from aws_encryption_sdk.internal.utils.commitment import (
+    validate_commitment_policy_on_decrypt,
+    validate_commitment_policy_on_encrypt,
+)
 from aws_encryption_sdk.key_providers.base import MasterKeyProvider
 from aws_encryption_sdk.materials_managers import DecryptionMaterialsRequest, EncryptionMaterialsRequest
 from aws_encryption_sdk.materials_managers.base import CryptoMaterialsManager
@@ -69,15 +70,11 @@ _LOGGER = logging.getLogger(__name__)
 
 @attr.s(hash=True)
 @six.add_metaclass(abc.ABCMeta)
-class _ClientConfig(object):  # pylint: disable=too-many-instance-attributes
+class _ClientConfig(object):
     """Parent configuration object for StreamEncryptor and StreamDecryptor objects.
 
     :param source: Source data to encrypt or decrypt
     :type source: str, bytes, io.IOBase, or file
-    :param commitment_policy: The commitment policy to use during encryption and decryption
-    :type commitment_policy: aws_encryption_sdk.identifiers.CommitmentPolicy
-    :param max_encrypted_data_keys: The maximum number of encrypted data keys to allow during encryption and decryption
-    :type max_encrypted_data_keys: None or positive int
     :param materials_manager: `CryptoMaterialsManager` from which to obtain cryptographic materials
         (either `materials_manager` or `key_provider` required)
     :type materials_manager: aws_encryption_sdk.materials_manager.base.CryptoMaterialsManager
@@ -92,8 +89,9 @@ class _ClientConfig(object):  # pylint: disable=too-many-instance-attributes
     """
 
     source = attr.ib(hash=True, converter=aws_encryption_sdk.internal.utils.prep_stream_data)
-    max_encrypted_data_keys = attr.ib(
-        hash=True, default=None, validator=attr.validators.optional(attr.validators.instance_of(int))
+    commitment_policy = attr.ib(
+        hash=True,
+        validator=attr.validators.instance_of(CommitmentPolicy),
     )
     materials_manager = attr.ib(
         hash=True, default=None, validator=attr.validators.optional(attr.validators.instance_of(CryptoMaterialsManager))
@@ -104,16 +102,6 @@ class _ClientConfig(object):  # pylint: disable=too-many-instance-attributes
     source_length = attr.ib(
         hash=True, default=None, validator=attr.validators.optional(attr.validators.instance_of(six.integer_types))
     )
-    commitment_policy = attr.ib(
-        hash=True,
-        default=CommitmentPolicy.FORBID_ENCRYPT_ALLOW_DECRYPT,
-        validator=attr.validators.optional(attr.validators.instance_of(CommitmentPolicy)),
-    )
-    signature_policy = attr.ib(
-        hash=True,
-        default=SignaturePolicy.ALLOW_ENCRYPT_ALLOW_DECRYPT,
-        validator=attr.validators.instance_of(SignaturePolicy),
-    )
     line_length = attr.ib(
         hash=True, default=LINE_LENGTH, validator=attr.validators.instance_of(six.integer_types)
     )  # DEPRECATED: Value is no longer configurable here.  Parameter left here to avoid breaking consumers.
@@ -443,8 +431,6 @@ class StreamEncryptor(_EncryptionStream):  # pylint: disable=too-many-instance-a
         :raises MasterKeyProviderError: if primary master key is not a member of supplied MasterKeyProvider
         :raises MasterKeyProviderError: if no Master Keys are returned from key_provider
         """
-        message_id = aws_encryption_sdk.internal.utils.message_id()
-
         validate_commitment_policy_on_encrypt(self.config.commitment_policy, self.config.algorithm)
 
         try:
@@ -473,10 +459,6 @@ class StreamEncryptor(_EncryptionStream):  # pylint: disable=too-many-instance-a
                 ).format(requested=self.config.algorithm, provided=self._encryption_materials.algorithm)
             )
 
-        num_keys = len(self._encryption_materials.encrypted_data_keys)
-        if self.config.max_encrypted_data_keys and num_keys > self.config.max_encrypted_data_keys:
-            raise MaxEncryptedDataKeysExceeded(num_keys, self.config.max_encrypted_data_keys)
-
         if self._encryption_materials.signing_key is None:
             self.signer = None
         else:
@@ -487,6 +469,10 @@ class StreamEncryptor(_EncryptionStream):  # pylint: disable=too-many-instance-a
             frame_length=self.config.frame_length, algorithm=self._encryption_materials.algorithm
         )
 
+        message_id = aws_encryption_sdk.internal.utils.message_id(
+            self._encryption_materials.algorithm.message_id_length()
+        )
+
         self._derived_data_key = derive_data_encryption_key(
             source_key=self._encryption_materials.data_encryption_key.data_key,
             algorithm=self._encryption_materials.algorithm,
@@ -746,7 +732,7 @@ class DecryptorConfig(_ClientConfig):
 
 
 class StreamDecryptor(_EncryptionStream):  # pylint: disable=too-many-instance-attributes
-    """Provides a streaming decryptor for decrypting a stream source.
+    """Provides a streaming encryptor for encrypting a stream source.
     Behaves as a standard file-like object.
 
     .. note::
@@ -786,6 +772,7 @@ class StreamDecryptor(_EncryptionStream):  # pylint: disable=too-many-instance-a
     def _prep_message(self):
         """Performs initial message setup."""
         self._header, self.header_auth = self._read_header()
+
         if self._header.content_type == ContentType.NO_FRAMING:
             self._prep_non_framed()
         self._message_prepped = True
@@ -797,12 +784,11 @@ class StreamDecryptor(_EncryptionStream):  # pylint: disable=too-many-instance-a
         :rtype: tuple of aws_encryption_sdk.structures.MessageHeader
             and aws_encryption_sdk.internal.structures.MessageHeaderAuthentication
         :raises CustomMaximumValueExceeded: if frame length is greater than the custom max value
-        :raises MaxEncryptedDataKeysExceeded: if number of encrypted data keys is greater than the custom max value
         """
-        header, raw_header = deserialize_header(self.source_stream, self.config.max_encrypted_data_keys)
+        header, raw_header = deserialize_header(self.source_stream)
         self.__unframed_bytes_read += len(raw_header)
 
-        validate_signature_policy_on_decrypt(self.config.signature_policy, header.algorithm)
+        validate_commitment_policy_on_decrypt(self.config.commitment_policy, header.algorithm)
 
         if (
             self.config.max_body_length is not None
@@ -991,3 +977,5 @@ class StreamDecryptor(_EncryptionStream):  # pylint: disable=too-many-instance-a
 
 
 __all__ = ("DecryptorConfig", "EncryptorConfig", "StreamDecryptor", "StreamEncryptor")
+
+# pylint: disable=too-many-lines
