@@ -20,13 +20,11 @@ from mock import MagicMock, call, patch, sentinel
 import aws_encryption_sdk.internal.defaults
 from aws_encryption_sdk.exceptions import (
     ActionNotAllowedError,
-    CustomMaximumValueExceeded,
     MasterKeyProviderError,
     NotSupportedError,
     SerializationError,
 )
 from aws_encryption_sdk.identifiers import Algorithm, CommitmentPolicy, ContentType, SerializationVersion
-from aws_encryption_sdk.internal.utils.signature import SignaturePolicy
 from aws_encryption_sdk.key_providers.base import MasterKey, MasterKeyProvider
 from aws_encryption_sdk.materials_managers.base import CryptoMaterialsManager
 from aws_encryption_sdk.streaming_client import StreamEncryptor
@@ -148,7 +146,7 @@ class TestStreamEncryptor(object):
         # Set up serialize_frame patch
         self.mock_serialize_frame_patcher = patch("aws_encryption_sdk.streaming_client.serialize_frame")
         self.mock_serialize_frame = self.mock_serialize_frame_patcher.start()
-        self.mock_signature_policy = MagicMock(__class__=SignaturePolicy)
+        self.mock_commitment_policy = MagicMock(__class__=CommitmentPolicy)
         yield
         # Run tearDown
         self.mock_content_type_patcher.stop()
@@ -169,25 +167,24 @@ class TestStreamEncryptor(object):
     def test_init(self):
         test_encryptor = StreamEncryptor(
             source=io.BytesIO(self.plaintext),
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             frame_length=self.mock_frame_length,
             algorithm=self.mock_algorithm,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         assert test_encryptor.sequence_number == 1
         self.mock_content_type.assert_called_once_with(self.mock_frame_length)
         assert test_encryptor.content_type is self.mock_content_type.return_value
-        assert test_encryptor.config.commitment_policy is CommitmentPolicy.FORBID_ENCRYPT_ALLOW_DECRYPT
 
     def test_init_non_framed_message_too_large(self):
         with pytest.raises(SerializationError) as excinfo:
             StreamEncryptor(
                 source=io.BytesIO(self.plaintext),
-                key_provider=self.mock_key_provider,
+                materials_manager=self.mock_materials_manager,
                 frame_length=0,
                 algorithm=self.mock_algorithm,
                 source_length=aws_encryption_sdk.internal.defaults.MAX_NON_FRAMED_SIZE + 1,
-                signature_policy=self.mock_signature_policy,
+                commitment_policy=self.mock_commitment_policy,
             )
         excinfo.match("Source too large for non-framed message")
 
@@ -198,8 +195,10 @@ class TestStreamEncryptor(object):
             key_provider=self.mock_key_provider,
             frame_length=self.mock_frame_length,
             source_length=5,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
+        test_encryptor.content_type = ContentType.FRAMED_DATA
+
         with pytest.raises(MasterKeyProviderError) as excinfo:
             test_encryptor._prep_message()
         excinfo.match("No Master Keys available from Master Key Provider")
@@ -214,51 +213,14 @@ class TestStreamEncryptor(object):
             key_provider=self.mock_key_provider,
             frame_length=self.mock_frame_length,
             source_length=5,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
+        test_encryptor.content_type = ContentType.FRAMED_DATA
 
         with pytest.raises(MasterKeyProviderError) as excinfo:
             test_encryptor._prep_message()
         excinfo.match("Primary Master Key not in provided Master Keys")
 
-    def test_prep_message_no_max_encrypted_data_keys(self):
-        test_encryptor = StreamEncryptor(
-            source=io.BytesIO(self.plaintext),
-            materials_manager=self.mock_materials_manager,
-            frame_length=self.mock_frame_length,
-            source_length=5,
-        )
-        self.mock_encryption_materials.encrypted_data_keys.__len__.return_value = 2 ** 16 - 1
-        test_encryptor.content_type = ContentType.FRAMED_DATA
-        test_encryptor._prep_message()
-
-    @pytest.mark.parametrize("num_keys", (2, 3))
-    def test_prep_message_within_max_encrypted_data_keys(self, num_keys):
-        test_encryptor = StreamEncryptor(
-            source=io.BytesIO(self.plaintext),
-            materials_manager=self.mock_materials_manager,
-            frame_length=self.mock_frame_length,
-            source_length=5,
-            max_encrypted_data_keys=3,
-        )
-        self.mock_encryption_materials.encrypted_data_keys.__len__.return_value = num_keys
-        test_encryptor.content_type = ContentType.FRAMED_DATA
-        test_encryptor._prep_message()
-
-    def test_prep_message_over_max_encrypted_data_keys(self):
-        test_encryptor = StreamEncryptor(
-            source=io.BytesIO(self.plaintext),
-            materials_manager=self.mock_materials_manager,
-            frame_length=self.mock_frame_length,
-            source_length=5,
-            max_encrypted_data_keys=3,
-        )
-        self.mock_encryption_materials.encrypted_data_keys.__len__.return_value = 4
-        test_encryptor.content_type = ContentType.FRAMED_DATA
-        with pytest.raises(CustomMaximumValueExceeded) as excinfo:
-            test_encryptor._prep_message()
-        excinfo.match("Number of encrypted data keys found larger than configured value")
-
     def test_prep_message_algorithm_change(self):
         self.mock_encryption_materials.algorithm = Algorithm.AES_256_GCM_IV12_TAG16
         test_encryptor = StreamEncryptor(
@@ -266,7 +228,7 @@ class TestStreamEncryptor(object):
             materials_manager=self.mock_materials_manager,
             algorithm=Algorithm.AES_128_GCM_IV12_TAG16,
             source_length=128,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         with pytest.raises(ActionNotAllowedError) as excinfo:
             test_encryptor._prep_message()
@@ -294,7 +256,7 @@ class TestStreamEncryptor(object):
             frame_length=self.mock_frame_length,
             source_length=5,
             encryption_context=VALUES["encryption_context"],
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.content_type = ContentType.FRAMED_DATA
         test_encryption_context = {aws_encryption_sdk.internal.defaults.ENCODED_SIGNER_KEY: sentinel.decoded_bytes}
@@ -309,7 +271,7 @@ class TestStreamEncryptor(object):
             plaintext_rostream=sentinel.plaintext_rostream,
             frame_length=test_encryptor.config.frame_length,
             plaintext_length=5,
-            commitment_policy=CommitmentPolicy.FORBID_ENCRYPT_ALLOW_DECRYPT,
+            commitment_policy=self.mock_commitment_policy,
         )
         self.mock_materials_manager.get_encryption_materials.assert_called_once_with(
             request=mock_encryption_materials_request.return_value
@@ -347,7 +309,7 @@ class TestStreamEncryptor(object):
             source=VALUES["data_128"],
             materials_manager=self.mock_materials_manager,
             frame_length=self.mock_frame_length,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.content_type = ContentType.NO_FRAMING
         test_encryptor._prep_message()
@@ -360,13 +322,14 @@ class TestStreamEncryptor(object):
             materials_manager=self.mock_materials_manager,
             frame_length=self.mock_frame_length,
             algorithm=Algorithm.AES_128_GCM_IV12_TAG16,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.content_type = ContentType.FRAMED_DATA
         test_encryptor._prep_message()
         assert not self.mock_signer.called
 
-    def test_prep_message_algorithm_violates_policy(self):
+    def test_commitment_committing_algorithm_not_allowed_by_policy(self):
+        """Verifies that we cannot encrypt with a committing algorithm with policy FORBID_ENCRYPT_REQUIRE_DECRYPT."""
         algorithm = MagicMock(__class__=Algorithm)
         algorithm.is_committing.return_value = True
         test_encryptor = StreamEncryptor(
@@ -375,14 +338,14 @@ class TestStreamEncryptor(object):
             frame_length=self.mock_frame_length,
             algorithm=algorithm,
             commitment_policy=CommitmentPolicy.FORBID_ENCRYPT_ALLOW_DECRYPT,
-            signature_policy=self.mock_signature_policy,
         )
 
         with pytest.raises(ActionNotAllowedError) as excinfo:
             test_encryptor._prep_message()
         excinfo.match("Configuration conflict. Cannot encrypt due to .* requiring only non-committed messages")
 
-    def test_prep_message_algorithm_allowed_by_policy(self):
+    def test_commitment_uncommitting_algorithm_allowed_by_policy(self):
+        """Verifies that we can encrypt with an uncommitting algorithm with policy FORBID_ENCRYPT_REQUIRE_DECRYPT."""
         algorithm = MagicMock(__class__=Algorithm, iv_len=12)
         algorithm.is_committing.return_value = False
         self.mock_encryption_materials.algorithm = algorithm
@@ -393,7 +356,52 @@ class TestStreamEncryptor(object):
             frame_length=self.mock_frame_length,
             algorithm=algorithm,
             commitment_policy=CommitmentPolicy.FORBID_ENCRYPT_ALLOW_DECRYPT,
-            signature_policy=self.mock_signature_policy,
+        )
+
+        test_encryptor._prep_message()
+
+    @pytest.mark.parametrize(
+        "policy", (CommitmentPolicy.REQUIRE_ENCRYPT_ALLOW_DECRYPT, CommitmentPolicy.REQUIRE_ENCRYPT_REQUIRE_DECRYPT)
+    )
+    def test_commitment_uncommitting_algorithm_not_allowed_by_policy(self, policy):
+        """Verifies that we cannot encrypt with an uncommitting algorithm with policies that require commitment on
+        encrypt."""
+        algorithm = MagicMock(__class__=Algorithm, iv_len=12)
+        algorithm.is_committing.return_value = False
+        self.mock_encryption_materials.algorithm = algorithm
+
+        test_encryptor = StreamEncryptor(
+            source=VALUES["data_128"],
+            materials_manager=self.mock_materials_manager,
+            frame_length=self.mock_frame_length,
+            algorithm=algorithm,
+            commitment_policy=policy,
+        )
+
+        with pytest.raises(ActionNotAllowedError) as excinfo:
+            test_encryptor._prep_message()
+        excinfo.match("Configuration conflict. Cannot encrypt due to .* requiring only committed messages")
+
+    @pytest.mark.parametrize(
+        "policy", (CommitmentPolicy.REQUIRE_ENCRYPT_ALLOW_DECRYPT, CommitmentPolicy.REQUIRE_ENCRYPT_REQUIRE_DECRYPT)
+    )
+    def test_commitment_committing_algorithm_required_by_policy(self, policy):
+        """Verifies that we can encrypt with a committing algorithm with policies that require commitment on
+        encrypt."""
+        mock_kdf = MagicMock()
+        mock_kdf.derive.return_value = b"somefakekey"
+        algorithm = MagicMock(__class__=Algorithm, iv_len=12)
+        algorithm.is_committing.return_value = True
+        algorithm.kdf_type.return_value = mock_kdf
+
+        self.mock_encryption_materials.algorithm = algorithm
+
+        test_encryptor = StreamEncryptor(
+            source=VALUES["data_128"],
+            materials_manager=self.mock_materials_manager,
+            frame_length=self.mock_frame_length,
+            algorithm=algorithm,
+            commitment_policy=policy,
         )
 
         test_encryptor._prep_message()
@@ -404,10 +412,10 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             algorithm=aws_encryption_sdk.internal.defaults.ALGORITHM,
             frame_length=self.mock_frame_length,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = sentinel.signer
         test_encryptor.content_type = sentinel.content_type
@@ -434,8 +442,8 @@ class TestStreamEncryptor(object):
         self.mock_serialize_non_framed_open.return_value = b"1234567890"
         test_encryptor = StreamEncryptor(
             source=io.BytesIO(self.plaintext),
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = sentinel.signer
         test_encryptor._encryption_materials = self.mock_encryption_materials
@@ -471,8 +479,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = MagicMock()
         test_encryptor.encryptor = MagicMock()
@@ -490,8 +498,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.bytes_read = aws_encryption_sdk.internal.defaults.MAX_NON_FRAMED_SIZE
         test_encryptor._StreamEncryptor__unframed_plaintext_cache = pt_stream
@@ -503,8 +511,8 @@ class TestStreamEncryptor(object):
     def test_read_bytes_to_non_framed_body_close(self):
         test_encryptor = StreamEncryptor(
             source=io.BytesIO(self.plaintext),
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = MagicMock()
         test_encryptor._encryption_materials = self.mock_encryption_materials
@@ -529,9 +537,9 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             algorithm=Algorithm.AES_128_GCM_IV12_TAG16,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor._header = MagicMock()
         test_encryptor.signer = None
@@ -551,8 +559,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.output_buffer = b"1234567"
         test_encryptor._read_bytes(5)
@@ -565,8 +573,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor._StreamEncryptor__message_complete = True
         test_encryptor._read_bytes(5)
@@ -579,8 +587,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.content_type = ContentType.FRAMED_DATA
         test_encryptor._read_bytes(5)
@@ -593,8 +601,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.content_type = ContentType.NO_FRAMING
         test_encryptor._read_bytes(5)
@@ -607,8 +615,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor._encryption_materials = self.mock_encryption_materials
         test_encryptor._header = MagicMock()
@@ -624,9 +632,9 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext * 2)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             frame_length=128,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = sentinel.signer
         test_encryptor._encryption_materials = self.mock_encryption_materials
@@ -654,9 +662,9 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext[:50])
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             frame_length=50,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = sentinel.signer
         test_encryptor._encryption_materials = self.mock_encryption_materials
@@ -705,9 +713,9 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             frame_length=frame_length,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = sentinel.signer
         test_encryptor._encryption_materials = self.mock_encryption_materials
@@ -780,9 +788,9 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             frame_length=len(self.plaintext),
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = sentinel.signer
         test_encryptor._encryption_materials = self.mock_encryption_materials
@@ -798,10 +806,10 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
+            materials_manager=self.mock_materials_manager,
             frame_length=len(self.plaintext),
             algorithm=Algorithm.AES_128_GCM_IV12_TAG16,
-            signature_policy=self.mock_signature_policy,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor.signer = None
         test_encryptor._encryption_materials = self.mock_encryption_materials
@@ -819,8 +827,8 @@ class TestStreamEncryptor(object):
         pt_stream = io.BytesIO(self.plaintext)
         test_encryptor = StreamEncryptor(
             source=pt_stream,
-            key_provider=self.mock_key_provider,
-            signature_policy=self.mock_signature_policy,
+            materials_manager=self.mock_materials_manager,
+            commitment_policy=self.mock_commitment_policy,
         )
         test_encryptor._derived_data_key = sentinel.derived_data_key
 
